timeout

Function timeout 

async fn timeout(
    store: &MockSuotarStore,
    generation: &str,
    args: &ScenarioArgs,
) -> Result<Value, CommandError>
sisuTimeout after the write leaves the world indistinguishable from a successful import, which is the case a client cannot resolve without verifying.